# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-03-17 17:16
from tqdm import tqdm

from django.conf import settings
from django.db import migrations, models
import django.utils.timezone


def move_alignment_samples_to_igv_model(apps, schema_editor):
    Sample = apps.get_model("seqr", "Sample")
    IgvSample = apps.get_model("seqr", "IgvSample")
    db_alias = schema_editor.connection.alias
    alignment_samples = Sample.objects.using(db_alias).filter(dataset_type='ALIGN')
    if alignment_samples:
        print('Transferring {} alignment samples'.format(len(alignment_samples)))
        created = IgvSample.objects.bulk_create([
            IgvSample(
                guid=sample.guid,
                file_path=sample.dataset_file_path,
                last_modified_date=sample.last_modified_date,
                individual=sample.individual,
                created_date=sample.created_date,
                created_by=sample.created_by,
            ) for sample in alignment_samples if sample.is_active])
        print('Successfully created {} active igv samples'.format(len(created)))
        print('Deleting old sample models')
        alignment_samples.delete()


def move_igv_models_to_alignment_samples(apps, schema_editor):
    Sample = apps.get_model("seqr", "Sample")
    IgvSample = apps.get_model("seqr", "IgvSample")
    db_alias = schema_editor.connection.alias
    alignment_samples = IgvSample.objects.using(db_alias).all()
    if alignment_samples:
        print('Transferring {} alignment samples'.format(len(alignment_samples)))
        Sample.objects.bulk_create([
            Sample(
                dataset_type='ALIGN',
                is_active=True,
                guid=sample.guid,
                dataset_file_path=sample.file_path,
                last_modified_date=sample.last_modified_date,
                individual=sample.individual,
                created_date=sample.created_date,
                created_by=sample.created_by,
            ) for sample in alignment_samples])
        print('Deleting old sample models')
        alignment_samples.delete()


def set_missing_es_indices(apps, schema_editor):
    Sample = apps.get_model("seqr", "Sample")
    db_alias = schema_editor.connection.alias
    missing_index_samples = Sample.objects.using(db_alias).filter(
        dataset_type='VARIANTS', is_active=False, elasticsearch_index__isnull=True)
    if missing_index_samples:
        print('Updating index for  {} samples'.format(len(missing_index_samples)))
        for sample in tqdm(missing_index_samples, unit=' samples'):
            sample.elasticsearch_index = sample.dataset_file_path
            sample.save()


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('seqr', '0007_auto_20200303_1842'),
    ]

    operations = [
        migrations.CreateModel(
            name='IgvSample',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('guid', models.CharField(db_index=True, max_length=30, unique=True)),
                ('created_date', models.DateTimeField(db_index=True, default=django.utils.timezone.now)),
                ('last_modified_date', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('file_path', models.TextField()),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('individual', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='seqr.Individual')),
            ],
        ),
        migrations.RunPython(move_alignment_samples_to_igv_model, reverse_code=move_igv_models_to_alignment_samples),
        migrations.RunPython(set_missing_es_indices, reverse_code=migrations.RunPython.noop),
        migrations.RemoveField(
            model_name='sample',
            name='dataset_file_path',
        ),
        migrations.AlterField(
            model_name='sample',
            name='dataset_type',
            field=models.CharField(choices=[('VARIANTS', 'Variant Calls'), ('SV', 'SV Calls')], max_length=10),
        ),
        migrations.AlterField(
            model_name='sample',
            name='elasticsearch_index',
            field=models.TextField(db_index=True),
        ),
        migrations.AlterField(
            model_name='sample',
            name='individual',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='seqr.Individual'),
        ),
        migrations.AlterField(
            model_name='sample',
            name='loaded_date',
            field=models.DateTimeField(),
        ),
        migrations.AlterField(
            model_name='sample',
            name='sample_type',
            field=models.CharField(choices=[('WES', 'Exome'), ('WGS', 'Whole Genome')], max_length=10),
        ),
    ]
