/* eslint-disable react/jsx-one-expression-per-line */

import React from 'react'
import { Header, Segment, List } from 'semantic-ui-react'

export default () => (
  <Segment basic padded="very">
    <Header dividing content="Terms Of Service" subheader="Last Updated 9/22/2023" size="huge" />

    Your access to systems and networks owned by The Broad Institute, Inc. (&quot;Broad&quot;) is governed by, and
    subject to the following terms and conditions, as well as all Federal laws, including, but not limited to, the
    Privacy Act, 5 U.S.C. 552a, if the applicable Broad system maintains individual Privacy Act information. Your access
    to Broad systems constitutes your consent to the retrieval and disclosure of the information within the scope of
    your authorized access, subject to the Privacy Act, and applicable State and Federal laws.

    <Header content="Cookies" size="medium" />
    seqr uses cookies to enable sign on and other essential features when signed in, and to provide statistics to our
    development team regarding how the site is used. For more information, see
    our <a href="/privacy_policy">Privacy Policy.</a>

    <Header content="Modification of the Agreement" size="medium" />
    Broad maintains the right to modify these Terms of Service at any time, and may do so by posting notice of such
    modifications on this page. Any modification made is effective immediately upon posting the modification (unless
    otherwise stated). You should visit this page periodically to review the current Terms of Service.

    <Header content="Conduct" size="medium" />
    You agree to access and use seqr for lawful purposes only. You are solely responsible for the knowledge of and
    adherence to any and all laws, statutes, rules, and regulations pertaining to your use of seqr.

    <Header content="By accessing and using seqr, you agree to:" size="small" />
    <List bulleted>
      <List.Item>
        Ensure that you have obtained all required consents, authorizations, and/or approvals needed to submit
        de-identified data.
      </List.Item>
      <List.Item>Share non-identifiable aggregate statistics with other users for research purposes.</List.Item>
      <List.Item>
        Access seqr using only your own individual account. Group or shared accounts are NOT permitted.
      </List.Item>
      <List.Item>
        Maintain the confidentiality of your authentication credentials such as your password. Do not reveal your
        authentication credentials to anyone; a Broad employee should never ask you to reveal them.
      </List.Item>
      <List.Item>
        Authentication is handled by <a href="https://app.terra.bio/" target="_blank" rel="noreferrer">Terra</a>.
        Users must meet password and MFA requirements per
        the <a href="https://app.terra.bio/#terms-of-service" target="_blank" rel="noreferrer">Terra Terms of Service</a>.
      </List.Item>
      <List.Item>
        Use multi-factor authentication and use a second factor authenticator that is both separate from the device
        gaining access to seqr and either FIPS 140-2 validated or NSA approved.
      </List.Item>
      <List.Item>
        Report all security incidents or suspected incidents (e.g., compromised passwords, improper or suspicious acts)
        related to Broad systems and networks to <a href="mailto:seqr@broadinstitute.org">seqr@broadinstitute.org</a>.
      </List.Item>
      <List.Item>
        Ensure that Web browsers use Secure Socket Layer (SSL) version 3.0 (or higher) and Transport Layer Security
        (TLS) 1.2 (or higher). SSL and TLS must use a minimum of 256-bit, encryption.
      </List.Item>
      <List.Item>
        Safeguard system resources against waste, loss, abuse, unauthorized use or disclosure, and misappropriation.
      </List.Item>
      <List.Item>
        Contact <a href="mailto:seqr@broadinstitute.org">seqr@broadinstitute.org</a> if you do not understand any of
        these rules.
      </List.Item>
    </List>

    <Header content="By accessing and using seqr, you agree that you must NOT:" size="small" />
    <List bulleted>
      <List.Item>
        Use seqr to commit a criminal offense, or to encourage others to conduct acts that would constitute a criminal
        offense or give rise to civil liability.
      </List.Item>
      <List.Item>
        Process U.S. classified national security information on the system.
      </List.Item>
      <List.Item>
        Browse, search or reveal any protected data by Broad except in accordance with that which is required to
        perform your legitimate tasks or assigned duties.
      </List.Item>
      <List.Item>
        Retrieve protected data or information, or in any other way disclose information, for someone who does not have
        authority to access that information.
      </List.Item>
      <List.Item>
        Establish any unauthorized interfaces between systems, networks, and applications owned by Broad.
      </List.Item>
      <List.Item>
        Upload any content that contains a software virus, such as a Trojan Horse or any other computer codes, files,
        or programs that may alter, damage, or interrupt the daily function of seqr and its users.
      </List.Item>
      <List.Item>Use portable storage devices in conjunction with the system.</List.Item>
      <List.Item>Post any material that infringes or violates the academic/intellectual rights of others.</List.Item>
      <List.Item>
        Use seqr to generate, distribute, publish, or facilitate unsolicited mass email, promotions, advertisements or
        other solicitations or mine for cryptocurrency.
      </List.Item>
    </List>

    <Header content="HIPAA, Protected Health Information, and the Clinical Compliance Features" size="medium" />
    Seqr is not a Covered Entity as that term is defined in the Health Insurance Portability and Accountability Act of
    1996, as amended, and its related regulations (collectively, &quot;HIPAA&quot;). seqr is not intended for the
    storage of any PHI on the platform. You agree to indemnify and hold harmless seqr of and from any and all claims,
    demands, losses, causes of action, damage, lawsuits, judgments, including attorneys&apos; fees and costs, arising
    out of or relating to your uploading, storing, or transferring of PHI.

    <Header content="Restrictions on the Use of Shared and Group Accounts" size="medium" />
    You may not access seqr using group or shared accounts. The credentials used for authenticating to seqr must
    belong to a single individual.

    <Header content="Access Levels" size="medium" />
    Your level of access to systems and networks owned by Broad is limited to ensure your access is no more than
    necessary to perform your legitimate tasks or assigned duties. If you believe you are being granted access that
    you should not have, you must immediately notify seqr@broadinstitute.org.

    <Header content="Granting Access" size="medium" />
    Some seqr users may have the ability to grant access to projects and the data contained therein. These users are
    responsible for ensuring that permission is granted only to those who have adequate permissions to work with that
    data. If data are shared inappropriately or with unauthorized users through seqr, your access to seqr may be
    suspended or terminated and, in some instances, seqr staff may contact the user&apos;s institution.

    <Header content="Termination of Use" size="medium" />
    We may in our sole discretion suspend/terminate your access to seqr without notification. We may also periodically
    review and remove accounts for which a user has not logged on.

    <Header content="External Links" size="medium" />
    seqr provides links that are maintained or controlled by external organizations. The listing of links are not an
    endorsement of information, products, or services, and do not imply a direct association between the Broad and the
    operators of the outside resource links.

    <Header content="Content" size="medium" />
    By accessing seqr, you expressly consent to monitoring of your actions and all content stored within the Platform.
    We reserve the right to delete, move, or edit any data, which we consider to be unacceptable or inappropriate.

    <Header content="Disclaimer of Warranty" size="medium" />
    You expressly understand and agree that your use of seqr, or any material available through it, is at your own risk.
    Neither the Broad nor its employees warrant that seqr will be uninterrupted, problem-free, free of omissions, or
    error-free; nor do they make any warranty as to the results that may be obtained from seqr.

    <Header content="Limitation of Liability" size="medium" />
    In no event will Broad, its affiliates or participating institutions, or their respective directors, officers,
    employees, faculty members or students be liable for any damages, include incidental, indirect, special, punitive,
    exemplary, or consequential damages, arising out of your use of or inability to use seqr, including without
    limitation, loss of revenue or anticipated profits, loss of goodwill, loss of data, computer failure or malfunction,
    or any and all other damages.
  </Segment>
)
